==> webkit2gtk_2.26.4.orig.tar.xz: webkitgtk-2.26.4/Source/bmalloc/bmalloc/IsoSharedHeap.h <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "IsoSharedConfig.h"
#include "IsoSharedPage.h"
#include "StaticPerProcess.h"

namespace bmalloc {

class AllIsoHeaps;

class VariadicBumpAllocator {
public:
    VariadicBumpAllocator() = default;

    VariadicBumpAllocator(char* payloadEnd, unsigned remaining)
        : m_payloadEnd(payloadEnd)
        , m_remaining(remaining)
    {
    }

    template<unsigned, typename Func>
    void* allocate(const Func& slowPath);

private:
    char* m_payloadEnd { nullptr };
    unsigned m_remaining { 0 };
};

class IsoSharedHeap : public StaticPerProcess<IsoSharedHeap> {
public:
    IsoSharedHeap(std::lock_guard<Mutex>&)
    {
    }

    template<unsigned>
    void* allocateNew(bool abortOnFailure);

private:
    template<unsigned>
    void* allocateSlow(bool abortOnFailure);

    IsoSharedPage* m_currentPage { nullptr };
    VariadicBumpAllocator m_allocator;
};
DECLARE_STATIC_PER_PROCESS_STORAGE(IsoSharedHeap);

} // namespace bmalloc

==> webkit2gtk_2.34.6.orig.tar.xz: webkitgtk-2.34.6/Source/bmalloc/bmalloc/IsoSharedHeap.h <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "IsoSharedConfig.h"
#include "IsoSharedPage.h"
#include "StaticPerProcess.h"

namespace bmalloc {

class AllIsoHeaps;

class VariadicBumpAllocator {
public:
    VariadicBumpAllocator() = default;

    VariadicBumpAllocator(char* payloadEnd, unsigned remaining)
        : m_payloadEnd(payloadEnd)
        , m_remaining(remaining)
    {
    }

    template<unsigned, typename Func>
    void* allocate(const Func& slowPath);

private:
    char* m_payloadEnd { nullptr };
    unsigned m_remaining { 0 };
};

class IsoSharedHeap : public StaticPerProcess<IsoSharedHeap> {
public:
    IsoSharedHeap(const LockHolder&)
    {
    }

    template<unsigned>
    void* allocateNew(bool abortOnFailure);

private:
    template<unsigned>
    void* allocateSlow(const LockHolder&, bool abortOnFailure);

    IsoSharedPage* m_currentPage { nullptr };
    VariadicBumpAllocator m_allocator;
};
DECLARE_STATIC_PER_PROCESS_STORAGE(IsoSharedHeap);

} // namespace bmalloc
